Flask-WTF
======================================

**Flask-WTF** offers simple integration with WTForms_.

.. _WTForms: http://wtforms.simplecodes.com/docs/

.. image:: https://pypip.in/wheel/flask-wtf/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/Flask-WTF/
   :alt: Wheel Status
.. image:: https://pypip.in/version/flask-wtf/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/Flask-WTF/
   :alt: Latest Version


Features
--------

* Integration with wtforms.
* Secure Form with csrf token.
* Global csrf protection.
* Recaptcha supporting.
* File upload that works with Flask-Uploads.
* Internationalization integration.

User's Guide
------------

This part of the documentation, which is mostly prose, begins with some
background information about Flask-WTF, then focuses on step-by-step
instructions for getting the most out of Flask-WTF.

.. toctree::
   :maxdepth: 2

   install
   quickstart
   form
   csrf
   config

API Documentation
-----------------

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

Additional Notes
----------------

Legal information and changelog are here.

.. toctree::
   :maxdepth: 2

   upgrade
   changelog
   authors
   license

.. _Flask: http://flask.pocoo.org
.. _GitHub: http://github.com/lepture/flask-wtf
